@@ -1,7 +1,9 @@
 package Acme::CPANModules::Org;
 
-our $DATE = '2020-01-12'; # DATE
-our $VERSION = '0.003'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-05-17'; # DATE
+our $DIST = 'Acme-CPANModules-Org'; # DIST
+our $VERSION = '0.004'; # VERSION
 
 our $LIST = {
     summary => "Modules related to Org format",
@@ -11,6 +13,7 @@ our $LIST = {
 _
     entries => [
         {module=>'App::org2wp'},
+        {module=>'App::orgdaemon'},
         {module=>'App::orgsel'},
         {module=>'App::OrgUtils'},
         {module=>'Data::CSel'},
@@ -43,18 +46,18 @@ Acme::CPANModules::Org - Modules related to Org format
 
 =head1 VERSION
 
-This document describes version 0.003 of Acme::CPANModules::Org (from Perl distribution Acme-CPANModules-Org), released on 2020-01-12.
+This document describes version 0.004 of Acme::CPANModules::Org (from Perl distribution Acme-CPANModules-Org), released on 2021-05-17.
 
 =head1 DESCRIPTION
 
-Modules related to Org format.
-
-=head1 INCLUDED MODULES
+=head1 ACME::CPANMODULES ENTRIES
 
 =over
 
 =item * L<App::org2wp>
 
+=item * L<App::orgdaemon>
+
 =item * L<App::orgsel>
 
 =item * L<App::OrgUtils>
@@ -87,10 +90,17 @@ Modules related to Org format.
 
 =head1 FAQ
 
-=head2 What are ways to use this module?
+=head2 What is an Acme::CPANModules::* module?
 
-Aside from reading it, you can install all the listed modules using
-L<cpanmodules>:
+An Acme::CPANModules::* module, like this module, contains just a list of module
+names that share a common characteristics. It is a way to categorize modules and
+document CPAN. See L<Acme::CPANModules> for more details.
+
+=head2 What are ways to use this Acme::CPANModules module?
+
+Aside from reading this Acme::CPANModules module's POD documentation, you can
+install all the listed modules (entries) using L<cpanmodules> CLI (from
+L<App::cpanmodules> distribution):
 
     % cpanmodules ls-entries Org | cpanm -n
 
@@ -98,9 +108,13 @@ or L<Acme::CM::Get>:
 
     % perl -MAcme::CM::Get=Org -E'say $_->{module} for @{ $LIST->{entries} }' | cpanm -n
 
-This module also helps L<lcpan> produce a more meaningful result for C<lcpan
-related-mods> when it comes to finding related modules for the modules listed
-in this Acme::CPANModules module.
+or directly:
+
+    % perl -MAcme::CPANModules::Org -E'say $_->{module} for @{ $Acme::CPANModules::Org::LIST->{entries} }' | cpanm -n
+
+This Acme::CPANModules module also helps L<lcpan> produce a more meaningful
+result for C<lcpan related-mods> command when it comes to finding related
+modules for the modules listed in this Acme::CPANModules module.
 
 =head1 HOMEPAGE
 
@@ -112,7 +126,7 @@ Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModules-Org
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModules-Org>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Acme-CPANModules-Org/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -132,7 +146,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2019 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2019 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
